Game_Interpreter.prototype.wait = function(duration) {
    this._waitCount = 1;
};

Window_BattleLog.prototype.updateWaitCount = function() {
    if (this._waitCount > 0) {
        this._waitCount = 0;
        return true;
    }
    return false;
};

Game_Character.prototype.updateRoutineMove = function() {
    if (this._waitCount > 0) {
        this._waitCount = 0;
    } else {
        this.setMovementSuccess(true);
        var command = this._moveRoute.list[this._moveRouteIndex];
        if (command) {
            this.processMoveCommand(command);
            this.advanceMoveRouteIndex();
        }
    }
};

Window_Message.prototype.updateWait = function() {
    return false;
};

Window_Message.prototype.startWait = function(count) {
    return;
};

/*Window_Message.prototype.startPause = function() {
    return;
};*/

Game_CharacterBase.prototype.realMoveSpeed = function() {
    return 7 + (this.isDashing() ? 1 : 0);
};

Game_Interpreter.prototype.updateWaitMode = function() {
    var waiting = false;
    switch (this._waitMode) {
    case 'message':
        waiting = $gameMessage.isBusy();
        break;
    case 'transfer':
        waiting = $gamePlayer.isTransferring();
        break;
    case 'scroll':
        waiting = $gameMap.isScrolling();
        break;
    case 'route':
        waiting = this._character.isMoveRouteForcing();
        break;
    case 'animation':
        waiting = this._character.isAnimationPlaying();
        break;
    case 'balloon':
        waiting = this._character.isBalloonPlaying();
        break;
    case 'gather':
        waiting = $gamePlayer.areFollowersGathering();
        break;
    case 'action':
        waiting = BattleManager.isActionForced();
        break;
    case 'video':
        waiting = Graphics.isVideoPlaying();
        break;
    case 'image':
        waiting = !ImageManager.isReady();
        break;
    }
    if (!waiting) {
        this._waitMode = '';
    }
    return waiting;
};

Game_Screen.prototype.startFadeOut = function(duration) {
    this._fadeOutDuration = 0;
    this._fadeInDuration = 0;
};

Game_Screen.prototype.startFadeIn = function(duration) {
    this._fadeInDuration = 0;
    this._fadeOutDuration = 0;
};

BattleManager.actionWaitForAnimation = function() {
    return false;
};

Scene_Gameover.prototype.createRetryWindows = function() {
    this._retryQuestion = new Window_Base(0, 0, 0, 0);
    this._retryQuestion.standardPadding = function() { return 4; };

    this._retryQuestion.initialize(0, 0, Graphics.boxWidth, 32);
    this._retryQuestion.contents.fontSize = 26;

    this._retryQuestion.x = 0;
    this._retryQuestion.y = 380 - 48;
    this._retryQuestion.drawOpacity = 0;
    this._retryQuestion.opacity = 0;
    this._retryQuestion.textToDraw = this._isFinalBattle && this._finalBattlePhase >= 5 ? LanguageManager.getMessageData("XX_BLUE.Yin_Omori_Fixes").continue : LanguageManager.getMessageData("XX_BLUE.Yin_Omori_Fixes").retry;
    this._retryQuestion.textDrawn = "";
    this._retryQuestion.textIndex = -1;
    this._retryQuestion.isTextComplete = function() {
        return this.textDrawn === this.textToDraw;
    }
    this._retryQuestion.textDelay = 0;
    // Making the text already visible;
    this._retryQuestion.drawOpacity = 255;
    this._retryQuestion.update = function(animPhase) {
        if (animPhase == 2 || animPhase == 3) {
            if(!!this.isTextComplete()) {return;}
            if(this.textDelay > 0) {return this.textDelay--;}
            if (!this.isTextComplete()) {
                this.contents.clear();
                this.textIndex = Math.min(this.textIndex + 1, this.textToDraw.length);
                this.textDrawn += this.textToDraw[this.textIndex];
                this.contents.paintOpacity = this.drawOpacity;
                this.contents.drawText(this.textDrawn, 0, -4, this.contents.width, this.contents.height, 'center');
                SoundManager.playMessageSound();
                this.textDelay = 0;
            }
        } else if (animPhase == 4) {
            this.contents.clear();
            this.drawOpacity -= 4;
            this.contents.paintOpacity = this.drawOpacity;
            this.contents.drawText(this.textDrawn, 0, -4, this.contents.width, this.contents.height, 'center');
        }
    };
    this.addChild(this._retryQuestion);
	
  // Initialize Retry Windows Array
  this._retryWindows = [];
  // List of text
  let text = [LanguageManager.getMessageData("XX_SYSTEM.message_10").text, LanguageManager.getMessageData("XX_SYSTEM.message_11").text];
  // Go Through Text
  for (let i = 0; i < text.length; i++) {
    let win = new Window_Base(0, 0, 0, 0);
    win.standardPadding = function() { return 4; };
    win.initialize(0, 0, win.contents.measureTextWidth(text[i]) + win.standardPadding() * 4, 32)
    win.contents.fontSize = 26;

    win.x = Math.floor(Graphics.boxWidth / 2.6) + i * 100
    win.y = 380;
    win.drawOpacity = 0;
    win.opacity = 0;
    win.textToDraw = text[i];
    win.update = function(animPhase) {
      if (animPhase == 2) {
        if(!this.parent._retryQuestion.isTextComplete()) {return;}
        if (this.drawOpacity < 255) {
          this.contents.clear();
          this.drawOpacity = 255;
          this.opacity = 255;
          this.contents.paintOpacity = this.drawOpacity;
          win.contents.drawText(this.textToDraw, 0, -4, this.contents.width, this.contents.height, 'center');
        }
      } else if (animPhase == 4) {
        this.contents.clear();
        this.drawOpacity -= 4;
        this.opacity -= 4;
        this.contents.paintOpacity = this.drawOpacity;
        win.contents.drawText(this.textToDraw, 0, -4, this.contents.width, this.contents.height, 'center');
      }
    };
    this._retryWindows.push(win);
    this.addChild(win);
  };
  // Set Max Input
  this._inputData.max = text.length;
  // Create Retry Cursor Sprite
  this._retryCursorSprite = new Sprite_WindowCustomCursor(undefined, 'cursor_menu');
  this._retryCursorSprite.opacity = 0;
  this.addChild(this._retryCursorSprite);
};

    Game_CharacterBase.prototype.fadeOut = function(numFrames) {
        this.fadeTo(0, 1);
    };

    Game_CharacterBase.prototype.fadeIn = function(numFrames) {
        this.fadeTo(255, 1);
    };